@@ -1,7 +1,7 @@
 package Pipe::Find;
 
-our $DATE = '2015-01-10'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-03-05'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -97,24 +97,24 @@ Pipe::Find - Find the processes behind the pipes that you open
 
 =head1 VERSION
 
-This document describes version 0.02 of Pipe::Find (from Perl distribution Pipe-Find), released on 2015-01-10.
+This document describes version 0.03 of Pipe::Find (from Perl distribution Pipe-Find), released on 2016-03-05.
 
 =head1 SYNOPSIS
 
  use Pipe::Find qw(find_pipe_processes get_stdout_pipe_process);
  $procs = find_pipe_processes(); # hashref, key=fd, value=process info hash
 
- if ($res->{0}) {
+ if ($procs->{0}) {
      say "STDIN is connected to a pipe";
      say "pid=$procs->{0}{pid}";
      say "cmdline=$procs->[0]{cmdline}";
      say "exe=$procs->[0]{exe}";
  }
- if ($res->{1}) {
+ if ($procs->{1}) {
      say "STDOUT is connected to a pipe";
      ...
  }
- if ($res->{3}) {
+ if ($procs->{3}) {
      say "STDERR is connected to a pipe";
      ...
  }
@@ -155,8 +155,6 @@ If you plan on getting process information for both STDIN and STDOUT, it's
 better to use C<find_pipe_processes()> than calling this function and
 C<get_stdin_pipe_process()>, because the latter will scan twice.
 
-=head1 SEE ALSO
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Pipe-Find>.
@@ -173,13 +171,15 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
